/*
 * RSSBot
 * Copyright (C) 2023 moonleay
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

package net.moonleay.rssbot.data.database.repository

import net.moonleay.rssbot.data.database.entry.RSSData
import net.moonleay.rssbot.data.database.tables.RSSTable
import org.jetbrains.exposed.sql.SqlExpressionBuilder.eq
import org.jetbrains.exposed.sql.and
import org.jetbrains.exposed.sql.deleteWhere
import org.jetbrains.exposed.sql.insert
import org.jetbrains.exposed.sql.select
import org.jetbrains.exposed.sql.transactions.transaction

object RSSRepository {
    fun exists(data: RSSData): Boolean = transaction {
        RSSTable.select {
            (RSSTable.guid eq data.guid) and (RSSTable.subscriptionId eq data.subscriptionId)
        }.count() > 0
    }

    fun write(data: RSSData) = transaction {
        RSSTable.insert {
            it[guid] = data.guid
            it[subscriptionId] = data.subscriptionId
        }
    }


    fun delete(subid: Int) = transaction {
        RSSTable.deleteWhere {
            RSSTable.subscriptionId eq subid
        }
    }
}
